@@ -22,6 +22,8 @@ DATA_TYPES = {
         }
     ]
 }
+COHORT_SUPPORTED_DATATYPES = ["Raw Counts Transcriptomics"]
+COHORT_SUPPORTED_DATASOURCES = ["GEO"]
 
 # validation flow files url github
 VALIDATION_FLOW_FILES_URL = (
@@ -118,6 +120,10 @@ FILES_PATH_FORMAT = {"metadata": "<metadata_path>", "data": "<data_path>"}
 
 INGESTION_FILES_PATH_DIR_NAMES = ["metadata", "data"]
 
+SCHEMA_CONFIG_KEY_NAMES = ["source", "datatype"]
+
+SCHEMA_CONFIG_FORMAT = {"source": "<source_name", "datatype": "<datatype_name>"}
+
 FORMATTED_METADATA = {"id": "", "type": "", "attributes": {}}
 
 FILE_FORMAT_CONSTANTS_URL = (
@@ -246,6 +252,14 @@ SCHEMA_VERDICT_DICT = {
     "no_change": SCHEMA_NO_CHANGE_SUCCESS,
 }
 
+VALIDATION_NOT_EXECUTED = (
+    "Validation not executed on any of the metadata files.  "
+    + "Possible reasons to help you troubleshoot :-"
+    + "\n"
+    + "All the metadata file passed may have `validate flag in the `__index__` dict to be "
+    + "false. Plese set them to true for the files which needs to be validated."
+)
+
 REPORT_GENERATION_SUPPORTED_REPOS = ["geo"]
 
 DELETION_OPERATION_UNSUCCESSFUL_FOR_ALL_DATASET_IDS = (
