@@ -318,7 +318,7 @@ def get_metadata(self, url: str, payload: dict) -> str:
     if not (hits and isinstance(hits, list)):
         raise paramException(
             title="Param Error",
-            detail="No matches found with the given repo details. Please try again.",
+            detail="No dataset matches found in the given repo. Please retry with the correct dataset ID.",
         )
     dataset = hits[0]
     return dataset
@@ -1013,3 +1013,21 @@ def make_query_for_discover_api(page_size, dataset_id):
         "size": page_size,
     }
     return query
+
+
+def read_json(path: str) -> json:
+    """
+    Function to read json content from a file.
+    """
+    with open(path) as filepath:
+        return json.load(filepath)
+
+
+def remove_prefix(text: str, prefix: str) -> str:
+    """
+    Function to remove prefix from text.
+    """
+    if text.startswith(prefix):
+        slice_obj = slice(len(prefix), len(text))
+        return text[slice_obj]
+    return text
