@@ -60,6 +60,21 @@ def parameter_check_for_repo_id(repo_id):
         )
 
 
+def parameter_check_for_dataset_id(dataset_id):
+    """Checking for validity of repo id
+    Args:
+        dataset_id (): Dataset Id of the dataset
+
+    Raises:
+        paramException: Error if dataset id is empty or is not str
+    """
+    if not (dataset_id and isinstance(dataset_id, str)):
+        raise paramException(
+            title="Param Error",
+            detail="Argument 'dataset_id' is either empty or invalid. It should be a string. Please try again.",
+        )
+
+
 def make_repo_id_string(repo_id: int) -> str:
     """If repo id is int, change to string
 
@@ -1230,9 +1245,11 @@ def list_files(
             next_endpoint = f"{self.discover_url}{next_link}"
             response = self.session.get(next_endpoint)
         else:
-            # getting the response for the first 1000 pages initially
+            # getting the response for the first 100 pages initially
+            # 100 page is set for now -> so that data does not max out
+            # TODO -> need to be optimised for page size and time
             query_params = {
-                "page[size]": 1000,
+                "page[size]": 100,
                 "page[after]": 0,
                 "include_metadata": f"{metadata}",
                 "data": f"{data}",
@@ -1645,3 +1662,69 @@ def handle_elastic_discover_api_error(response):
             details,
         ) = extract_error_message_details(response)
         raise Exception("Exception Occurred :" + str(details))
+
+
+def normalise_destination_path(self, destination_folder_path: str, repo_id: str) -> str:
+    status_info = return_destination_folder_status(
+        self, destination_folder_path, repo_id
+    )
+    pathExists = status_info[0]
+    # if destination_folder does not exist, then normalise the path, otherwise not
+    if not pathExists:
+        destination_folder_path = return_normalise_destination_path(
+            destination_folder_path
+        )
+    return destination_folder_path
+
+
+def return_normalise_destination_path(destination_folder_path: str) -> str:
+    normalised_path = os.path.normpath(destination_folder_path)
+    return normalised_path
+
+
+def return_destination_folder_status(
+    self, destination_folder_path: str, repo_id: str
+) -> tuple:
+    """
+    Function to check if the destination_folder_path already exist.
+    Args:
+        destination_folder_path (str): destination folder passed
+        repo_id(str): repo_id of the repository
+    """
+    list_oa_response = list_files(self, repo_id, metadata=False)
+    oa_data_files_list = []
+    for response in list_oa_response:
+        response_json = response.json()
+        response_data = response_json.get("data")
+        for item in response_data:
+            file_id = item.get("id")
+            oa_data_files_list.append(file_id)
+
+    valid_folder_list = helpers.get_folder_list_from_list_of_filepaths(
+        oa_data_files_list
+    )
+
+    # return status(whether destination_folder_path exists or not) and valid_folder_list as a tuple
+
+    if destination_folder_path not in valid_folder_list:
+        return False, valid_folder_list
+    return True, valid_folder_list
+
+
+def check_params_for_fetch_quilt_metadata(repo_key, dataset_id):
+    """
+    Args:
+        repo_key(str/int): repo_name/repo_id of the repository.
+        dataset_id(str): dataset_id of the dataset.
+    """
+    if not (repo_key and (isinstance(repo_key, str) or isinstance(repo_key, int))):
+        raise paramException(
+            title="Param Error",
+            detail="Argument 'repo_key' is either empty or invalid. \
+It should either be a string or an integer. Please try again.",
+        )
+    if not (dataset_id and isinstance(dataset_id, str)):
+        raise paramException(
+            title="Param Error",
+            detail="Argument 'dataset_id' is either empty or invalid. It should be a string. Please try again.",
+        )
