@@ -25,6 +25,8 @@ from polly.errors import error_handler
 from polly.validation import Validation
 from test_constants import INGESTION_TEST_1_REPO_ID, MOCK_RESPONSE_DOWNLOAD_DATA
 
+from polly_validator.validators import dataset_metadata_validator
+
 # from botocore.exceptions import ClientError
 
 
@@ -1661,6 +1663,8 @@ def test_update_dataset_new_data_file_without_metadata_file():
             pytest.fail("Expected a warning!")
 
 
+# TODO make changes in the tests when new validation flow of
+# multi source, multi datatype is integrated
 def test_update_dataset_metadata_file_with_wrong_extension():
     Polly.auth(testpolly_token, env="testpolly")
     omix_obj = omixatlas.OmixAtlas()
@@ -1698,7 +1702,23 @@ def test_update_dataset_metadata_file_with_wrong_extension():
         omix_obj.update_datasets(repo_id, source_folder_path, destination_folder)
 
 
-def test_validation_addition_datasets_full_flow():
+@pytest.fixture()
+def get_validatation_lib_mock_fixture():
+    data = ["a", "b", "c"]
+    empty_df = pd.DataFrame(data)
+
+    err_dataset = empty_df
+    status_dict = {
+        "ACBC_MSKCC_2015_Copy_Number_AdCC10T": False,
+        "ACBC_MSKCC_2015_Copy_Number_AdCC12T": False,
+    }
+
+    return err_dataset, status_dict
+
+
+def test_validation_addition_datasets_full_flow(
+    mocker, get_validatation_lib_mock_fixture
+):
     Polly.auth(testpolly_token, env="testpolly")
     omix_obj = omixatlas.OmixAtlas()
     validation_obj = Validation()
@@ -1794,9 +1814,19 @@ def test_validation_addition_datasets_full_flow():
 
     source_folder_path = {"data": data_path, "metadata": metadata_path}
     destination_folder = "transcriptomics_test"
+    schema_config = {}
+    schema_config["source"] = "geo"
+    schema_config["datatype"] = "all"
+
+    # mock validation library response
+
+    mocker.patch(
+        dataset_metadata_validator.__name__ + ".check_metadata_for_errors",
+        return_value=get_validatation_lib_mock_fixture,
+    )
 
     err_dataset_df, status_dict = validation_obj.validate_datasets(
-        repo_id, source_folder_path
+        repo_id, source_folder_path, schema_config=schema_config
     )
 
     assert isinstance(err_dataset_df, pd.DataFrame)
@@ -1813,8 +1843,8 @@ def test_validation_addition_datasets_full_flow():
     # coming in `res_df`
     # 1 more file `combined_metadata` file will be uploaded
     # TODO: revert to back to 3 value once the validation lib issues are fixed
-    # assert res_df.shape[0] == 3
-    assert res_df.shape[0] == 5
+    assert res_df.shape[0] == 3
+    # assert res_df.shape[0] == 5
 
 
 # DLS_BB057_CV244_AML_BMMC_ATAC088_ATAC089_GEX062_GEX063_MTDNA073_MTDNA074_0.05rnaclustres_0.05corr.zip
@@ -1907,13 +1937,48 @@ def test_validation_addition_datasets_full_flow():
 #     assert "file_metadata" in types_in_metadata_dict
 
 
-def test_get_metadata():
+@pytest.fixture()
+def get_metadata_fixture():
+    """Get geo metadata from github"""
+    base_polly_py_test_url = test_const.POLLY_PY_TEST_FILES_URL
+
+    data_file = f"{base_polly_py_test_url}/geo_get_metadata_response.json"
+    data = requests.get(data_file)
+    error_handler(data)
+    return data
+
+
+@pytest.fixture()
+def get_metadata_empty_hits_fixture():
+    """Get response with empty hits from github"""
+    base_polly_py_test_url = test_const.POLLY_PY_TEST_FILES_URL
+
+    data_file = f"{base_polly_py_test_url}/final_pagination_mocked_response.json"
+    data = requests.get(data_file)
+    error_handler(data)
+    return data
+
+
+@pytest.fixture()
+def get_metadata_csv_fixture():
+    """Get geo metadata csv file from github"""
+    base_polly_py_test_url = test_const.POLLY_PY_TEST_FILES_URL
+
+    data_file = f"{base_polly_py_test_url}/geo_get_metadata_test_df.csv"
+    try:
+        data_df = pd.read_csv(data_file)
+    except Exception as err:
+        raise err
+    return data_df
+
+
+def test_get_metadata(mocker, get_metadata_csv_fixture):
     Polly.auth(token)
     obj = omixatlas.OmixAtlas()
     correct_repo_name = "geo"
     correct_repo_id = 9
     incorrect_repo_key = [9]
-    correct_dataset_id = "GSE100053_GPL10558"
+    correct_dataset_id = "GSE199927_GPL19057"
     incorrect_dataset_id = 1234
     correct_table_name = "samples"
     incorrect_table_name = "datasets"
@@ -1942,6 +2007,82 @@ def test_get_metadata():
         match=r".*Argument 'repo_key' is either empty or invalid. .*",
     ):
         obj.get_metadata(incorrect_repo_key, correct_dataset_id, correct_table_name)
+    dataframe_result = get_metadata_csv_fixture
+    mocker.patch(
+        polly.omixatlas.__name__ + ".OmixAtlas._retrieve_dataframe",
+        return_value=dataframe_result,
+    )
+    result = obj.get_metadata(correct_repo_name, correct_dataset_id, correct_table_name)
+    assert result.equals(dataframe_result) is True
+
+
+def test_retrieve_dataframe(mocker, get_metadata_fixture, get_metadata_csv_fixture):
+    Polly.auth(token)
+    obj = omixatlas.OmixAtlas()
+    index = "geo_gct_col_metadata"
+    discover_url = (
+        f"https://api.datalake.discover.{obj.session.env}.elucidata.io/elastic/v2"
+    )
+    page_size = 1000
+    dataset_id = "GSE199927_GPL19057"
+    intermediate_result = get_metadata_fixture
+    dataframe_result = get_metadata_csv_fixture
+    mocker.patch(
+        polly.omixatlas.__name__ + ".OmixAtlas._initiate_retrieval",
+        return_value=intermediate_result,
+    )
+    mocker.patch(
+        polly.omixatlas.__name__ + ".OmixAtlas._complete_retrieval",
+        return_value=dataframe_result,
+    )
+    result = obj._retrieve_dataframe(discover_url, page_size, dataset_id, index)
+    assert isinstance(result, pd.DataFrame)
+
+
+def test_initiate_retrieval(mocker, get_metadata_fixture):
+    Polly.auth(token)
+    obj = omixatlas.OmixAtlas()
+    dataframe_result = get_metadata_fixture
+    response = mocker.patch.object(obj.session, "post")
+    response.return_value.status_code = 200
+    response.return_value = dataframe_result
+    index = "geo_gct_col_metadata"
+    discover_url = (
+        f"https://api.datalake.discover.{obj.session.env}.elucidata.io/elastic/v2"
+    )
+    page_size = 1000
+    dataset_id = "GSE199927_GPL19057"
+    query = {
+        "query": {
+            "term": {
+                # Count entries for the following key-value pairs
+                "src_dataset_id.keyword": dataset_id
+            }
+        },
+        # Fetch X many rows at a time (you will still get the full output, which may be greater than 10K)
+        # Setting this value to be greater than 10k will result in an error
+        "size": page_size,
+    }
+    result = obj._initiate_retrieval(discover_url, query, index)
+    assert isinstance(result, dict)
+
+
+def test_complete_retrieval(
+    mocker, get_metadata_fixture, get_metadata_empty_hits_fixture
+):
+    Polly.auth(token)
+    obj = omixatlas.OmixAtlas()
+    dataframe_result = get_metadata_empty_hits_fixture
+    response = mocker.patch.object(obj.session, "post")
+    response.return_value.status_code = 200
+    response.return_value = dataframe_result
+    discover_url = (
+        f"https://api.datalake.discover.{obj.session.env}.elucidata.io/elastic/v2"
+    )
+    intermediate_result = get_metadata_fixture
+    json_arg = json.loads(intermediate_result.text)
+    result = obj._complete_retrieval(discover_url, json_arg)
+    assert isinstance(result, pd.DataFrame)
 
 
 @pytest.fixture()
@@ -2146,6 +2287,68 @@ def test_update_schema_body_wrong_format():
         omix_obj.update_schema(repo_id, body)
 
 
+# replace schema tests
+# replace schema test 1 -> positive case
+def test_replace_schema_positive_case(
+    mocker, validate_schema_mock_fixture, capsys, get_ingestion_test_1_schema_fixture
+):
+    # Doing it on a repo that already exists
+    # 1st -> Mock response of `_get_omixatlas()` call
+    # inside validate schema -> make a seperate mocked function for that
+    mocker.patch(
+        polly.omixatlas.__name__ + ".OmixAtlas.validate_schema",
+        return_value=validate_schema_mock_fixture,
+    )
+
+    # then mocking the response of PUT API CALL for Replace Schema
+    Polly.auth(testpolly_token, env="testpolly")
+    nobj = omixatlas.OmixAtlas()
+    # mocked response with status and no specific value
+    # as no specific response is mocked -> generic message will be printed
+    response = mocker.patch.object(nobj.session, "put")
+    response.return_value.status_code = 200
+
+    # ingestion_test_1
+    repo_id = test_const.INGESTION_TEST_1_REPO_ID
+
+    body = get_ingestion_test_1_schema_fixture
+
+    nobj.replace_schema(repo_id, body)
+    # when successfully run
+    # comparing the print in the function is coming out
+    # in the stdout
+    captured = capsys.readouterr()
+    assert "Schema replace is in progress" in captured.out
+
+
+# replace schema test 2 -> repo_id wrong format
+def test_replace_schema_repo_id_wrong_format(get_ingestion_test_1_schema_fixture):
+    Polly.auth(testpolly_token, env="testpolly")
+    omix_obj = omixatlas.OmixAtlas()
+    repo_id = [test_const.INGESTION_TEST_1_REPO_ID]
+    body = get_ingestion_test_1_schema_fixture
+
+    with pytest.raises(
+        paramException,
+        match=r".should be str or int",
+    ):
+        omix_obj.replace_schema(repo_id, body)
+
+
+# replace schema test 3 -> body wrong format
+def test_replace_schema_body_wrong_format():
+    Polly.auth(testpolly_token, env="testpolly")
+    omix_obj = omixatlas.OmixAtlas()
+    repo_id = test_const.INGESTION_TEST_1_REPO_ID
+    body = "abcd"
+
+    with pytest.raises(
+        paramException,
+        match=r"body should not be empty and it should be of type dict",
+    ):
+        omix_obj.replace_schema(repo_id, body)
+
+
 def test_check_omixatlas_status(mocker, capsys, get_omixatlas_mock_fixture):
     Polly.auth(testpolly_token, env="testpolly")
     obj = omixatlas.OmixAtlas()
